@@ -6,6 +6,7 @@
     clippy::redundant_closure
 )]
 
+use anyhow::{anyhow, bail, Context, Result};
 mod npm;
 
 use std::path::Path;
@@ -14,12 +15,12 @@ use std::{collections::HashMap, fs};
 use self::npm::{
     repository::Repository, CommonJSPackage, ESModulesPackage, NoModulesPackage, NpmPackage,
 };
+use crate::command::build::{BuildProfile, Target};
+use crate::PBAR;
 use cargo_metadata::Metadata;
 use chrono::offset;
 use chrono::DateTime;
-use command::build::{BuildProfile, Target};
 use curl::easy;
-use failure::{Error, ResultExt};
 use serde::{self, Deserialize};
 use serde_json;
 use std::collections::BTreeSet;
@@ -27,7 +28,6 @@ use std::env;
 use std::io::Write;
 use strsim::levenshtein;
 use toml;
-use PBAR;
 
 const WASM_PACK_METADATA_KEY: &str = "package.metadata.wasm-pack";
 const WASM_PACK_VERSION: Option<&'static str> = option_env!("CARGO_PKG_VERSION");
@@ -50,12 +50,6 @@ pub struct CargoManifest {
 #[derive(Deserialize)]
 struct CargoPackage {
     name: String,
-    description: Option<String>,
-    license: Option<String>,
-    #[serde(rename = "license-file")]
-    license_file: Option<String>,
-    repository: Option<String>,
-    homepage: Option<String>,
 
     #[serde(default)]
     metadata: CargoMetadata,
@@ -149,7 +143,7 @@ struct CrateInformation {
 
 impl Crate {
     /// Returns latest wasm-pack version
-    pub fn return_wasm_pack_latest_version() -> Result<Option<String>, failure::Error> {
+    pub fn return_wasm_pack_latest_version() -> Result<Option<String>> {
         let current_time = chrono::offset::Local::now();
         let old_metadata_file = Self::return_wasm_pack_file();
 
@@ -172,9 +166,7 @@ impl Crate {
         }
     }
 
-    fn return_api_call_result(
-        current_time: DateTime<offset::Local>,
-    ) -> Result<String, failure::Error> {
+    fn return_api_call_result(current_time: DateTime<offset::Local>) -> Result<String> {
         let version = Self::return_latest_wasm_pack_version();
 
         // We always override the stamp file with the current time because we don't
@@ -192,7 +184,7 @@ impl Crate {
     fn override_stamp_file(
         current_time: DateTime<offset::Local>,
         version: Option<&str>,
-    ) -> Result<(), failure::Error> {
+    ) -> Result<()> {
         let path = env::current_exe()?;
 
         let mut file = fs::OpenOptions::new()
@@ -224,7 +216,7 @@ impl Crate {
     }
 
     /// Returns wasm-pack latest version (if it's received) by executing check_wasm_pack_latest_version function.
-    fn return_latest_wasm_pack_version() -> Result<String, failure::Error> {
+    fn return_latest_wasm_pack_version() -> Result<String> {
         Self::check_wasm_pack_latest_version().map(|crt| crt.crt.max_version)
     }
 
@@ -239,7 +231,7 @@ impl Crate {
     }
 
     /// Call to the crates.io api and return the latest version of `wasm-pack`
-    fn check_wasm_pack_latest_version() -> Result<Crate, Error> {
+    fn check_wasm_pack_latest_version() -> Result<Crate> {
         let url = "https://crates.io/api/v1/crates/wasm-pack";
 
         let mut easy = easy::Easy2::new(Collector(Vec::new()));
@@ -403,7 +395,7 @@ pub struct ManifestAndUnsedKeys {
 impl CrateData {
     /// Reads all metadata for the crate whose manifest is inside the directory
     /// specified by `path`.
-    pub fn new(crate_path: &Path, out_name: Option<String>) -> Result<CrateData, Error> {
+    pub fn new(crate_path: &Path, out_name: Option<String>) -> Result<CrateData> {
         let manifest_path = crate_path.join("Cargo.toml");
         if !manifest_path.is_file() {
             bail!(
@@ -426,9 +418,9 @@ impl CrateData {
             .iter()
             .position(|pkg| {
                 pkg.name == manifest.package.name
-                    && CrateData::is_same_path(&pkg.manifest_path, &manifest_path)
+                    && CrateData::is_same_path(pkg.manifest_path.as_std_path(), &manifest_path)
             })
-            .ok_or_else(|| format_err!("failed to find package in metadata"))?;
+            .ok_or_else(|| anyhow!("failed to find package in metadata"))?;
 
         Ok(CrateData {
             data,
@@ -454,9 +446,9 @@ impl CrateData {
     /// # Errors
     /// Will return Err if the file (manifest_path) couldn't be read or
     /// if deserialize to `CargoManifest` fails.
-    pub fn parse_crate_data(manifest_path: &Path) -> Result<ManifestAndUnsedKeys, Error> {
+    pub fn parse_crate_data(manifest_path: &Path) -> Result<ManifestAndUnsedKeys> {
         let manifest = fs::read_to_string(&manifest_path)
-            .with_context(|_| format!("failed to read: {}", manifest_path.display()))?;
+            .with_context(|| anyhow!("failed to read: {}", manifest_path.display()))?;
         let manifest = &mut toml::Deserializer::new(&manifest);
 
         let mut unused_keys = BTreeSet::new();
@@ -472,7 +464,7 @@ impl CrateData {
                 unused_keys.insert(path_string);
             }
         })
-        .with_context(|_| format!("failed to parse manifest: {}", manifest_path.display()))?;
+        .with_context(|| anyhow!("failed to parse manifest: {}", manifest_path.display()))?;
 
         Ok(ManifestAndUnsedKeys {
             manifest,
@@ -501,12 +493,12 @@ impl CrateData {
     }
 
     /// Check that the crate the given path is properly configured.
-    pub fn check_crate_config(&self) -> Result<(), Error> {
+    pub fn check_crate_config(&self) -> Result<()> {
         self.check_crate_type()?;
         Ok(())
     }
 
-    fn check_crate_type(&self) -> Result<(), Error> {
+    fn check_crate_type(&self) -> Result<()> {
         let pkg = &self.data.packages[self.current_idx];
         let any_cdylib = pkg
             .targets
@@ -524,9 +516,13 @@ impl CrateData {
         )
     }
 
+    fn pkg(&self) -> &cargo_metadata::Package {
+        &self.data.packages[self.current_idx]
+    }
+
     /// Get the crate name for the crate at the given path.
     pub fn crate_name(&self) -> String {
-        let pkg = &self.data.packages[self.current_idx];
+        let pkg = self.pkg();
         match pkg
             .targets
             .iter()
@@ -547,12 +543,15 @@ impl CrateData {
 
     /// Get the license for the crate at the given path.
     pub fn crate_license(&self) -> &Option<String> {
-        &self.manifest.package.license
+        &self.pkg().license
     }
 
     /// Get the license file path for the crate at the given path.
-    pub fn crate_license_file(&self) -> &Option<String> {
-        &self.manifest.package.license_file
+    pub fn crate_license_file(&self) -> Option<String> {
+        self.pkg()
+            .license_file
+            .clone()
+            .map(|license_file| license_file.into_string())
     }
 
     /// Returns the path to this project's target directory where artifacts are
@@ -573,7 +572,7 @@ impl CrateData {
         scope: &Option<String>,
         disable_dts: bool,
         target: Target,
-    ) -> Result<(), Error> {
+    ) -> Result<()> {
         let pkg_file_path = out_dir.join("package.json");
         // Check if a `package.json` was already generated by wasm-bindgen, if so
         // we merge the NPM dependencies already specified in it.
@@ -590,12 +589,14 @@ impl CrateData {
             Target::NoModules => self.to_nomodules(scope, disable_dts, existing_deps, out_dir),
             Target::Bundler => self.to_esmodules(scope, disable_dts, existing_deps, out_dir),
             Target::Web => self.to_web(scope, disable_dts, existing_deps, out_dir),
+            // Deno does not need package.json
+            Target::Deno => return Ok(()),
         };
 
         let npm_json = serde_json::to_string_pretty(&npm_data)?;
 
         fs::write(&pkg_file_path, npm_json)
-            .with_context(|_| format!("failed to write: {}", pkg_file_path.display()))?;
+            .with_context(|| anyhow!("failed to write: {}", pkg_file_path.display()))?;
         Ok(())
     }
 
@@ -654,14 +655,14 @@ impl CrateData {
             dts_file,
             files,
             main: js_file,
-            homepage: self.manifest.package.homepage.clone(),
+            homepage: self.pkg().homepage.clone(),
             keywords,
         }
     }
 
     fn license(&self) -> Option<String> {
-        self.manifest.package.license.clone().or_else(|| {
-            self.manifest.package.license_file.clone().map(|file| {
+        self.crate_license().clone().or_else(|| {
+            self.crate_license_file().clone().map(|file| {
                 // When license is written in file: https://docs.npmjs.com/files/package.json#license
                 format!("SEE LICENSE IN {}", file)
             })
@@ -683,18 +684,13 @@ impl CrateData {
         NpmPackage::CommonJSPackage(CommonJSPackage {
             name: data.name,
             collaborators: pkg.authors.clone(),
-            description: self.manifest.package.description.clone(),
+            description: self.pkg().description.clone(),
             version: pkg.version.to_string(),
             license: self.license(),
-            repository: self
-                .manifest
-                .package
-                .repository
-                .clone()
-                .map(|repo_url| Repository {
-                    ty: "git".to_string(),
-                    url: repo_url,
-                }),
+            repository: self.pkg().repository.clone().map(|repo_url| Repository {
+                ty: "git".to_string(),
+                url: repo_url,
+            }),
             files: data.files,
             main: data.main,
             homepage: data.homepage,
@@ -719,23 +715,18 @@ impl CrateData {
         NpmPackage::ESModulesPackage(ESModulesPackage {
             name: data.name,
             collaborators: pkg.authors.clone(),
-            description: self.manifest.package.description.clone(),
+            description: self.pkg().description.clone(),
             version: pkg.version.to_string(),
             license: self.license(),
-            repository: self
-                .manifest
-                .package
-                .repository
-                .clone()
-                .map(|repo_url| Repository {
-                    ty: "git".to_string(),
-                    url: repo_url,
-                }),
+            repository: self.pkg().repository.clone().map(|repo_url| Repository {
+                ty: "git".to_string(),
+                url: repo_url,
+            }),
             files: data.files,
-            module: data.main,
+            module: data.main.clone(),
             homepage: data.homepage,
             types: data.dts_file,
-            side_effects: false,
+            side_effects: vec![format!("./{}", data.main), "./snippets/*".to_owned()],
             keywords: data.keywords,
             dependencies,
         })
@@ -756,23 +747,18 @@ impl CrateData {
         NpmPackage::ESModulesPackage(ESModulesPackage {
             name: data.name,
             collaborators: pkg.authors.clone(),
-            description: self.manifest.package.description.clone(),
+            description: self.pkg().description.clone(),
             version: pkg.version.to_string(),
             license: self.license(),
-            repository: self
-                .manifest
-                .package
-                .repository
-                .clone()
-                .map(|repo_url| Repository {
-                    ty: "git".to_string(),
-                    url: repo_url,
-                }),
+            repository: self.pkg().repository.clone().map(|repo_url| Repository {
+                ty: "git".to_string(),
+                url: repo_url,
+            }),
             files: data.files,
             module: data.main,
             homepage: data.homepage,
             types: data.dts_file,
-            side_effects: false,
+            side_effects: vec!["./snippets/*".to_owned()],
             keywords: data.keywords,
             dependencies,
         })
@@ -793,18 +779,13 @@ impl CrateData {
         NpmPackage::NoModulesPackage(NoModulesPackage {
             name: data.name,
             collaborators: pkg.authors.clone(),
-            description: self.manifest.package.description.clone(),
+            description: self.pkg().description.clone(),
             version: pkg.version.to_string(),
             license: self.license(),
-            repository: self
-                .manifest
-                .package
-                .repository
-                .clone()
-                .map(|repo_url| Repository {
-                    ty: "git".to_string(),
-                    url: repo_url,
-                }),
+            repository: self.pkg().repository.clone().map(|repo_url| Repository {
+                ty: "git".to_string(),
+                url: repo_url,
+            }),
             files: data.files,
             browser: data.main,
             homepage: data.homepage,
@@ -816,13 +797,13 @@ impl CrateData {
 
     fn check_optional_fields(&self) {
         let mut messages = vec![];
-        if self.manifest.package.description.is_none() {
+        if self.pkg().description.is_none() {
             messages.push("description");
         }
-        if self.manifest.package.repository.is_none() {
+        if self.pkg().repository.is_none() {
             messages.push("repository");
         }
-        if self.manifest.package.license.is_none() && self.manifest.package.license_file.is_none() {
+        if self.pkg().license.is_none() && self.pkg().license_file.is_none() {
             messages.push("license");
         }
 
