@@ -1,11 +1,11 @@
+use crate::utils::{self, fixture};
 use assert_cmd::prelude::*;
 use std::collections::{HashMap, HashSet};
 use std::fs;
 use std::path::PathBuf;
-use utils::{self, fixture};
 use wasm_pack::command::build::Target;
 use wasm_pack::command::utils::get_crate_path;
-use wasm_pack::{self, license, manifest};
+use wasm_pack::{self, emoji, license, manifest};
 
 #[test]
 fn it_gets_the_crate_name_default_path() {
@@ -93,7 +93,10 @@ fn it_creates_a_package_json_default_path() {
     );
     assert_eq!(pkg.module, "js_hello_world.js");
     assert_eq!(pkg.types, "js_hello_world.d.ts");
-    assert_eq!(pkg.side_effects, false);
+    assert_eq!(
+        pkg.side_effects,
+        vec!["./js_hello_world.js", "./snippets/*"]
+    );
 
     let actual_files: HashSet<String> = pkg.files.into_iter().collect();
     let expected_files: HashSet<String> = [
@@ -255,7 +258,7 @@ fn it_creates_a_package_json_with_correct_files_when_out_name_is_provided() {
     );
     assert_eq!(pkg.module, "index.js");
     assert_eq!(pkg.types, "index.d.ts");
-    assert_eq!(pkg.side_effects, false);
+    assert_eq!(pkg.side_effects, vec!["./index.js", "./snippets/*"]);
 
     let actual_files: HashSet<String> = pkg.files.into_iter().collect();
     let expected_files: HashSet<String> =
@@ -559,10 +562,11 @@ fn parse_crate_data_returns_unused_keys_in_cargo_toml() {
         .arg("build")
         .assert()
         .success()
-        .stderr(predicates::str::contains(
-        "[WARN]: :-) \"package.metadata.wasm-pack.profile.production\" is an unknown key and will \
+        .stderr(predicates::str::contains(format!(
+        "[WARN]: {} \"package.metadata.wasm-pack.profile.production\" is an unknown key and will \
          be ignored. Please check your Cargo.toml.",
-    ));
+        emoji::WARN
+    )));
 }
 
 #[test]
